Module: Aws::IoTEventsData

Defined in:
lib/aws-sdk-ioteventsdata/endpoint_parameters.rb,
sig/client.rbs,
sig/errors.rbs,
sig/waiters.rbs,
sig/resource.rbs,
lib/aws-sdk-ioteventsdata/plugins/endpoints.rb,
lib/aws-sdk-ioteventsdata/endpoint_provider.rb,
lib/aws-sdk-ioteventsdata/client_api.rb,
lib/aws-sdk-ioteventsdata/endpoints.rb,
lib/aws-sdk-ioteventsdata/resource.rb,
lib/aws-sdk-ioteventsdata/errors.rb,
lib/aws-sdk-ioteventsdata/client.rb,
lib/aws-sdk-ioteventsdata/types.rb,
lib/aws-sdk-ioteventsdata.rb

Overview

This module provides support for AWS IoT Events Data. This module is available in the aws-sdk-ioteventsdata gem.

Client

The Client class provides one method for each API operation. Operation methods each accept a hash of request parameters and return a response structure.

io_t_events_data = Aws::IoTEventsData::Client.new
resp = io_t_events_data.batch_acknowledge_alarm(params)

See Client for more information.

Errors

Errors returned from AWS IoT Events Data are defined in the Errors module and all extend Errors::ServiceError.

begin
  # do stuff
rescue Aws::IoTEventsData::Errors::ServiceError
  # rescues all AWS IoT Events Data API errors
end

See Errors for more information.

Defined Under Namespace

Modules: ClientApi, Endpoints, Errors, Plugins, Types, Waiters Classes: Client, EndpointParameters, EndpointProvider, Resource

service collapse

GEM_VERSION =
'1.77.0'