Class: Aws::IoTEventsData::Types::BatchResetAlarmResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ioteventsdata/types.rb

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#error_entriesArray<Types::BatchAlarmActionErrorEntry>

A list of errors associated with the request, or `null` if there are no errors. Each error entry contains an entry ID that helps you identify the entry that failed.



539
540
541
542
543
# File 'lib/aws-sdk-ioteventsdata/types.rb', line 539

class BatchResetAlarmResponse < Struct.new(
  :error_entries)
  SENSITIVE = []
  include Aws::Structure
end