Class: Aws::IoTEventsData::Types::DescribeAlarmRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ioteventsdata/types.rb

Overview

Note:

When making an API call, you may pass DescribeAlarmRequest data as a hash:

{
  alarm_model_name: "AlarmModelName", # required
  key_value: "KeyValue",
}

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#alarm_model_nameString

The name of the alarm model.

Returns:

  • (String)


776
777
778
779
780
781
# File 'lib/aws-sdk-ioteventsdata/types.rb', line 776

class DescribeAlarmRequest < Struct.new(
  :alarm_model_name,
  :key_value)
  SENSITIVE = []
  include Aws::Structure
end

#key_valueString

The value of the key used as a filter to select only the alarms associated with the [key].

[1]: docs.aws.amazon.com/iotevents/latest/apireference/API_CreateAlarmModel.html#iotevents-CreateAlarmModel-request-key

Returns:

  • (String)


776
777
778
779
780
781
# File 'lib/aws-sdk-ioteventsdata/types.rb', line 776

class DescribeAlarmRequest < Struct.new(
  :alarm_model_name,
  :key_value)
  SENSITIVE = []
  include Aws::Structure
end