Class: Aws::IoTEventsData::Types::DescribeDetectorRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTEventsData::Types::DescribeDetectorRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ioteventsdata/types.rb
Overview
Note:
When making an API call, you may pass DescribeDetectorRequest data as a hash:
{
detector_model_name: "DetectorModelName", # required
key_value: "KeyValue",
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#detector_model_name ⇒ String
The name of the detector model whose detectors (instances) you want information about.
-
#key_value ⇒ String
A filter used to limit results to detectors (instances) created because of the given key ID.
Instance Attribute Details
#detector_model_name ⇒ String
The name of the detector model whose detectors (instances) you want information about.
811 812 813 814 815 816 |
# File 'lib/aws-sdk-ioteventsdata/types.rb', line 811 class DescribeDetectorRequest < Struct.new( :detector_model_name, :key_value) SENSITIVE = [] include Aws::Structure end |
#key_value ⇒ String
A filter used to limit results to detectors (instances) created because of the given key ID.
811 812 813 814 815 816 |
# File 'lib/aws-sdk-ioteventsdata/types.rb', line 811 class DescribeDetectorRequest < Struct.new( :detector_model_name, :key_value) SENSITIVE = [] include Aws::Structure end |