Class: Aws::IoTEventsData::Types::Detector

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ioteventsdata/types.rb

Overview

Information about the detector (instance).

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#creation_time ⇒ Time

The time the detector (instance) was created.



694
695
696
697
698
699
700
701
702
703
# File 'lib/aws-sdk-ioteventsdata/types.rb', line 694

class Detector < Struct.new(
  :detector_model_name,
  :key_value,
  :detector_model_version,
  :state,
  :creation_time,
  :last_update_time)
  SENSITIVE = []
  include Aws::Structure
end

#detector_model_name ⇒ String

The name of the detector model that created this detector (instance).



694
695
696
697
698
699
700
701
702
703
# File 'lib/aws-sdk-ioteventsdata/types.rb', line 694

class Detector < Struct.new(
  :detector_model_name,
  :key_value,
  :detector_model_version,
  :state,
  :creation_time,
  :last_update_time)
  SENSITIVE = []
  include Aws::Structure
end

#detector_model_version ⇒ String

The version of the detector model that created this detector (instance).



694
695
696
697
698
699
700
701
702
703
# File 'lib/aws-sdk-ioteventsdata/types.rb', line 694

class Detector < Struct.new(
  :detector_model_name,
  :key_value,
  :detector_model_version,
  :state,
  :creation_time,
  :last_update_time)
  SENSITIVE = []
  include Aws::Structure
end

#key_value ⇒ String

The value of the key (identifying the device or system) that caused the creation of this detector (instance).



694
695
696
697
698
699
700
701
702
703
# File 'lib/aws-sdk-ioteventsdata/types.rb', line 694

class Detector < Struct.new(
  :detector_model_name,
  :key_value,
  :detector_model_version,
  :state,
  :creation_time,
  :last_update_time)
  SENSITIVE = []
  include Aws::Structure
end

#last_update_time ⇒ Time

The time the detector (instance) was last updated.



694
695
696
697
698
699
700
701
702
703
# File 'lib/aws-sdk-ioteventsdata/types.rb', line 694

class Detector < Struct.new(
  :detector_model_name,
  :key_value,
  :detector_model_version,
  :state,
  :creation_time,
  :last_update_time)
  SENSITIVE = []
  include Aws::Structure
end

#state ⇒ Types::DetectorState

The current state of the detector (instance).



694
695
696
697
698
699
700
701
702
703
# File 'lib/aws-sdk-ioteventsdata/types.rb', line 694

class Detector < Struct.new(
  :detector_model_name,
  :key_value,
  :detector_model_version,
  :state,
  :creation_time,
  :last_update_time)
  SENSITIVE = []
  include Aws::Structure
end