Class: Aws::IoTEventsData::Types::DetectorStateDefinition
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTEventsData::Types::DetectorStateDefinition
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ioteventsdata/types.rb
Overview
Note:
When making an API call, you may pass DetectorStateDefinition data as a hash:
{
state_name: "StateName", # required
variables: [ # required
{
name: "VariableName", # required
value: "VariableValue", # required
},
],
timers: [ # required
{
name: "TimerName", # required
seconds: 1, # required
},
],
}
The new state, variable values, and timer settings of the detector (instance).
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#state_name ⇒ String
The name of the new state of the detector (instance).
-
#timers ⇒ Array<Types::TimerDefinition>
The new values of the detector's timers.
-
#variables ⇒ Array<Types::VariableDefinition>
The new values of the detector's variables.
Instance Attribute Details
#state_name ⇒ String
The name of the new state of the detector (instance).
826 827 828 829 830 831 832 |
# File 'lib/aws-sdk-ioteventsdata/types.rb', line 826 class DetectorStateDefinition < Struct.new( :state_name, :variables, :timers) SENSITIVE = [] include Aws::Structure end |
#timers ⇒ Array<Types::TimerDefinition>
The new values of the detector's timers. Any timer whose value isn't specified is cleared, and its timeout event won't occur.
826 827 828 829 830 831 832 |
# File 'lib/aws-sdk-ioteventsdata/types.rb', line 826 class DetectorStateDefinition < Struct.new( :state_name, :variables, :timers) SENSITIVE = [] include Aws::Structure end |
#variables ⇒ Array<Types::VariableDefinition>
The new values of the detector's variables. Any variable whose value isn't specified is cleared.
826 827 828 829 830 831 832 |
# File 'lib/aws-sdk-ioteventsdata/types.rb', line 826 class DetectorStateDefinition < Struct.new( :state_name, :variables, :timers) SENSITIVE = [] include Aws::Structure end |