Class: Aws::IoTEventsData::Types::EnableActionConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTEventsData::Types::EnableActionConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ioteventsdata/types.rb
Overview
Contains the configuration information of an enable action.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#note ⇒ String
The note that you can leave when you enable the alarm.
Instance Attribute Details
#note ⇒ String
The note that you can leave when you enable the alarm.
946 947 948 949 950 |
# File 'lib/aws-sdk-ioteventsdata/types.rb', line 946 class EnableActionConfiguration < Struct.new( :note) SENSITIVE = [] include Aws::Structure end |