Class: Aws::IoTEventsData::Types::EnableAlarmActionRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ioteventsdata/types.rb

Overview

Note:

When making an API call, you may pass EnableAlarmActionRequest data as a hash:

{
  request_id: "RequestId", # required
  alarm_model_name: "AlarmModelName", # required
  key_value: "KeyValue",
  note: "Note",
}

Information needed to enable the alarm.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#alarm_model_nameString

The name of the alarm model.

Returns:

  • (String)


1085
1086
1087
1088
1089
1090
1091
1092
# File 'lib/aws-sdk-ioteventsdata/types.rb', line 1085

class EnableAlarmActionRequest < Struct.new(
  :request_id,
  :alarm_model_name,
  :key_value,
  :note)
  SENSITIVE = []
  include Aws::Structure
end

#key_valueString

The value of the key used as a filter to select only the alarms associated with the [key].

[1]: docs.aws.amazon.com/iotevents/latest/apireference/API_CreateAlarmModel.html#iotevents-CreateAlarmModel-request-key

Returns:

  • (String)


1085
1086
1087
1088
1089
1090
1091
1092
# File 'lib/aws-sdk-ioteventsdata/types.rb', line 1085

class EnableAlarmActionRequest < Struct.new(
  :request_id,
  :alarm_model_name,
  :key_value,
  :note)
  SENSITIVE = []
  include Aws::Structure
end

#noteString

The note that you can leave when you enable the alarm.

Returns:

  • (String)


1085
1086
1087
1088
1089
1090
1091
1092
# File 'lib/aws-sdk-ioteventsdata/types.rb', line 1085

class EnableAlarmActionRequest < Struct.new(
  :request_id,
  :alarm_model_name,
  :key_value,
  :note)
  SENSITIVE = []
  include Aws::Structure
end

#request_idString

The request ID. Each ID must be unique within each batch.

Returns:

  • (String)


1085
1086
1087
1088
1089
1090
1091
1092
# File 'lib/aws-sdk-ioteventsdata/types.rb', line 1085

class EnableAlarmActionRequest < Struct.new(
  :request_id,
  :alarm_model_name,
  :key_value,
  :note)
  SENSITIVE = []
  include Aws::Structure
end