Class: Aws::IoTEventsData::Types::Message
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTEventsData::Types::Message
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ioteventsdata/types.rb
Overview
Note:
When making an API call, you may pass Message data as a hash:
{
message_id: "MessageId", # required
input_name: "EphemeralInputName", # required
payload: "data", # required
timestamp: {
time_in_millis: 1,
},
}
Information about a message.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#input_name ⇒ String
The name of the input into which the message payload is transformed.
-
#message_id ⇒ String
The ID to assign to the message.
-
#payload ⇒ String
The payload of the message.
-
#timestamp ⇒ Types::TimestampValue
The timestamp associated with the message.
Instance Attribute Details
#input_name ⇒ String
The name of the input into which the message payload is transformed.
1249 1250 1251 1252 1253 1254 1255 1256 |
# File 'lib/aws-sdk-ioteventsdata/types.rb', line 1249 class Message < Struct.new( :message_id, :input_name, :payload, :timestamp) SENSITIVE = [] include Aws::Structure end |
#message_id ⇒ String
The ID to assign to the message. Within each batch sent, each `“messageId”` must be unique.
1249 1250 1251 1252 1253 1254 1255 1256 |
# File 'lib/aws-sdk-ioteventsdata/types.rb', line 1249 class Message < Struct.new( :message_id, :input_name, :payload, :timestamp) SENSITIVE = [] include Aws::Structure end |
#payload ⇒ String
The payload of the message. This can be a JSON string or a Base-64-encoded string representing binary data (in which case you must decode it).
1249 1250 1251 1252 1253 1254 1255 1256 |
# File 'lib/aws-sdk-ioteventsdata/types.rb', line 1249 class Message < Struct.new( :message_id, :input_name, :payload, :timestamp) SENSITIVE = [] include Aws::Structure end |
#timestamp ⇒ Types::TimestampValue
The timestamp associated with the message.
1249 1250 1251 1252 1253 1254 1255 1256 |
# File 'lib/aws-sdk-ioteventsdata/types.rb', line 1249 class Message < Struct.new( :message_id, :input_name, :payload, :timestamp) SENSITIVE = [] include Aws::Structure end |