Class: Aws::IoTEventsData::Types::SnoozeAlarmActionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTEventsData::Types::SnoozeAlarmActionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ioteventsdata/types.rb
Overview
Note:
When making an API call, you may pass SnoozeAlarmActionRequest data as a hash:
{
request_id: "RequestId", # required
alarm_model_name: "AlarmModelName", # required
key_value: "KeyValue",
note: "Note",
snooze_duration: 1, # required
}
Information needed to snooze the alarm.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#alarm_model_name ⇒ String
The name of the alarm model.
-
#key_value ⇒ String
The value of the key used as a filter to select only the alarms associated with the [key].
-
#note ⇒ String
The note that you can leave when you snooze the alarm.
-
#request_id ⇒ String
The request ID.
-
#snooze_duration ⇒ Integer
The snooze time in seconds.
Instance Attribute Details
#alarm_model_name ⇒ String
The name of the alarm model.
1328 1329 1330 1331 1332 1333 1334 1335 1336 |
# File 'lib/aws-sdk-ioteventsdata/types.rb', line 1328 class SnoozeAlarmActionRequest < Struct.new( :request_id, :alarm_model_name, :key_value, :note, :snooze_duration) SENSITIVE = [] include Aws::Structure end |
#key_value ⇒ String
The value of the key used as a filter to select only the alarms associated with the [key].
1328 1329 1330 1331 1332 1333 1334 1335 1336 |
# File 'lib/aws-sdk-ioteventsdata/types.rb', line 1328 class SnoozeAlarmActionRequest < Struct.new( :request_id, :alarm_model_name, :key_value, :note, :snooze_duration) SENSITIVE = [] include Aws::Structure end |
#note ⇒ String
The note that you can leave when you snooze the alarm.
1328 1329 1330 1331 1332 1333 1334 1335 1336 |
# File 'lib/aws-sdk-ioteventsdata/types.rb', line 1328 class SnoozeAlarmActionRequest < Struct.new( :request_id, :alarm_model_name, :key_value, :note, :snooze_duration) SENSITIVE = [] include Aws::Structure end |
#request_id ⇒ String
The request ID. Each ID must be unique within each batch.
1328 1329 1330 1331 1332 1333 1334 1335 1336 |
# File 'lib/aws-sdk-ioteventsdata/types.rb', line 1328 class SnoozeAlarmActionRequest < Struct.new( :request_id, :alarm_model_name, :key_value, :note, :snooze_duration) SENSITIVE = [] include Aws::Structure end |
#snooze_duration ⇒ Integer
The snooze time in seconds. The alarm automatically changes to the `NORMAL` state after this duration.
1328 1329 1330 1331 1332 1333 1334 1335 1336 |
# File 'lib/aws-sdk-ioteventsdata/types.rb', line 1328 class SnoozeAlarmActionRequest < Struct.new( :request_id, :alarm_model_name, :key_value, :note, :snooze_duration) SENSITIVE = [] include Aws::Structure end |