Class: Aws::IoTEventsData::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::IoTEventsData::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-ioteventsdata/client.rb
Overview
An API client for IoTEventsData. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::IoTEventsData::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#batch_acknowledge_alarm(params = {}) ⇒ Types::BatchAcknowledgeAlarmResponse
Acknowledges one or more alarms.
-
#batch_delete_detector(params = {}) ⇒ Types::BatchDeleteDetectorResponse
Deletes one or more detectors that were created.
-
#batch_disable_alarm(params = {}) ⇒ Types::BatchDisableAlarmResponse
Disables one or more alarms.
-
#batch_enable_alarm(params = {}) ⇒ Types::BatchEnableAlarmResponse
Enables one or more alarms.
-
#batch_put_message(params = {}) ⇒ Types::BatchPutMessageResponse
Sends a set of messages to the IoT Events system.
-
#batch_reset_alarm(params = {}) ⇒ Types::BatchResetAlarmResponse
Resets one or more alarms.
-
#batch_snooze_alarm(params = {}) ⇒ Types::BatchSnoozeAlarmResponse
Changes one or more alarms to the snooze mode.
-
#batch_update_detector(params = {}) ⇒ Types::BatchUpdateDetectorResponse
Updates the state, variable values, and timer settings of one or more detectors (instances) of a specified detector model.
-
#describe_alarm(params = {}) ⇒ Types::DescribeAlarmResponse
Retrieves information about an alarm.
-
#describe_detector(params = {}) ⇒ Types::DescribeDetectorResponse
Returns information about the specified detector (instance).
-
#list_alarms(params = {}) ⇒ Types::ListAlarmsResponse
Lists one or more alarms.
-
#list_detectors(params = {}) ⇒ Types::ListDetectorsResponse
Lists detectors (the instances of a detector model).
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
476 477 478 |
# File 'lib/aws-sdk-ioteventsdata/client.rb', line 476 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1029 1030 1031 |
# File 'lib/aws-sdk-ioteventsdata/client.rb', line 1029 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1032 1033 1034 |
# File 'lib/aws-sdk-ioteventsdata/client.rb', line 1032 def errors_module Errors end |
Instance Method Details
#batch_acknowledge_alarm(params = {}) ⇒ Types::BatchAcknowledgeAlarmResponse
Acknowledges one or more alarms. The alarms change to the ‘ACKNOWLEDGED` state after you acknowledge them.
515 516 517 518 |
# File 'lib/aws-sdk-ioteventsdata/client.rb', line 515 def batch_acknowledge_alarm(params = {}, = {}) req = build_request(:batch_acknowledge_alarm, params) req.send_request() end |
#batch_delete_detector(params = {}) ⇒ Types::BatchDeleteDetectorResponse
Deletes one or more detectors that were created. When a detector is deleted, its state will be cleared and the detector will be removed from the list of detectors. The deleted detector will no longer appear if referenced in the [ListDetectors] API call.
[1]: docs.aws.amazon.com/iotevents/latest/apireference/API_iotevents-data_ListDetectors.html
557 558 559 560 |
# File 'lib/aws-sdk-ioteventsdata/client.rb', line 557 def batch_delete_detector(params = {}, = {}) req = build_request(:batch_delete_detector, params) req.send_request() end |
#batch_disable_alarm(params = {}) ⇒ Types::BatchDisableAlarmResponse
Disables one or more alarms. The alarms change to the ‘DISABLED` state after you disable them.
595 596 597 598 |
# File 'lib/aws-sdk-ioteventsdata/client.rb', line 595 def batch_disable_alarm(params = {}, = {}) req = build_request(:batch_disable_alarm, params) req.send_request() end |
#batch_enable_alarm(params = {}) ⇒ Types::BatchEnableAlarmResponse
Enables one or more alarms. The alarms change to the ‘NORMAL` state after you enable them.
633 634 635 636 |
# File 'lib/aws-sdk-ioteventsdata/client.rb', line 633 def batch_enable_alarm(params = {}, = {}) req = build_request(:batch_enable_alarm, params) req.send_request() end |
#batch_put_message(params = {}) ⇒ Types::BatchPutMessageResponse
Sends a set of messages to the IoT Events system. Each message payload is transformed into the input you specify (‘“inputName”`) and ingested into any detectors that monitor that input. If multiple messages are sent, the order in which the messages are processed isn’t guaranteed. To guarantee ordering, you must send messages one at a time and wait for a successful response.
678 679 680 681 |
# File 'lib/aws-sdk-ioteventsdata/client.rb', line 678 def (params = {}, = {}) req = build_request(:batch_put_message, params) req.send_request() end |
#batch_reset_alarm(params = {}) ⇒ Types::BatchResetAlarmResponse
Resets one or more alarms. The alarms return to the ‘NORMAL` state after you reset them.
716 717 718 719 |
# File 'lib/aws-sdk-ioteventsdata/client.rb', line 716 def batch_reset_alarm(params = {}, = {}) req = build_request(:batch_reset_alarm, params) req.send_request() end |
#batch_snooze_alarm(params = {}) ⇒ Types::BatchSnoozeAlarmResponse
Changes one or more alarms to the snooze mode. The alarms change to the ‘SNOOZE_DISABLED` state after you set them to the snooze mode.
755 756 757 758 |
# File 'lib/aws-sdk-ioteventsdata/client.rb', line 755 def batch_snooze_alarm(params = {}, = {}) req = build_request(:batch_snooze_alarm, params) req.send_request() end |
#batch_update_detector(params = {}) ⇒ Types::BatchUpdateDetectorResponse
Updates the state, variable values, and timer settings of one or more detectors (instances) of a specified detector model.
807 808 809 810 |
# File 'lib/aws-sdk-ioteventsdata/client.rb', line 807 def batch_update_detector(params = {}, = {}) req = build_request(:batch_update_detector, params) req.send_request() end |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1002 1003 1004 1005 1006 1007 1008 1009 1010 1011 1012 1013 1014 1015 1016 1017 1018 |
# File 'lib/aws-sdk-ioteventsdata/client.rb', line 1002 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::IoTEventsData') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-ioteventsdata' context[:gem_version] = '1.62.0' Seahorse::Client::Request.new(handlers, context) end |
#describe_alarm(params = {}) ⇒ Types::DescribeAlarmResponse
Retrieves information about an alarm.
860 861 862 863 |
# File 'lib/aws-sdk-ioteventsdata/client.rb', line 860 def describe_alarm(params = {}, = {}) req = build_request(:describe_alarm, params) req.send_request() end |
#describe_detector(params = {}) ⇒ Types::DescribeDetectorResponse
Returns information about the specified detector (instance).
903 904 905 906 |
# File 'lib/aws-sdk-ioteventsdata/client.rb', line 903 def describe_detector(params = {}, = {}) req = build_request(:describe_detector, params) req.send_request() end |
#list_alarms(params = {}) ⇒ Types::ListAlarmsResponse
Lists one or more alarms. The operation returns only the metadata associated with each alarm.
946 947 948 949 |
# File 'lib/aws-sdk-ioteventsdata/client.rb', line 946 def list_alarms(params = {}, = {}) req = build_request(:list_alarms, params) req.send_request() end |
#list_detectors(params = {}) ⇒ Types::ListDetectorsResponse
Lists detectors (the instances of a detector model).
993 994 995 996 |
# File 'lib/aws-sdk-ioteventsdata/client.rb', line 993 def list_detectors(params = {}, = {}) req = build_request(:list_detectors, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1022 1023 1024 |
# File 'lib/aws-sdk-ioteventsdata/client.rb', line 1022 def waiter_names [] end |