Class: Aws::IoTEventsData::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::IoTEventsData::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-ioteventsdata/client.rb
Overview
An API client for IoTEventsData. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::IoTEventsData::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#batch_acknowledge_alarm(params = {}) ⇒ Types::BatchAcknowledgeAlarmResponse
Acknowledges one or more alarms.
-
#batch_delete_detector(params = {}) ⇒ Types::BatchDeleteDetectorResponse
Deletes one or more detectors that were created.
-
#batch_disable_alarm(params = {}) ⇒ Types::BatchDisableAlarmResponse
Disables one or more alarms.
-
#batch_enable_alarm(params = {}) ⇒ Types::BatchEnableAlarmResponse
Enables one or more alarms.
-
#batch_put_message(params = {}) ⇒ Types::BatchPutMessageResponse
Sends a set of messages to the IoT Events system.
-
#batch_reset_alarm(params = {}) ⇒ Types::BatchResetAlarmResponse
Resets one or more alarms.
-
#batch_snooze_alarm(params = {}) ⇒ Types::BatchSnoozeAlarmResponse
Changes one or more alarms to the snooze mode.
-
#batch_update_detector(params = {}) ⇒ Types::BatchUpdateDetectorResponse
Updates the state, variable values, and timer settings of one or more detectors (instances) of a specified detector model.
-
#describe_alarm(params = {}) ⇒ Types::DescribeAlarmResponse
Retrieves information about an alarm.
-
#describe_detector(params = {}) ⇒ Types::DescribeDetectorResponse
Returns information about the specified detector (instance).
-
#list_alarms(params = {}) ⇒ Types::ListAlarmsResponse
Lists one or more alarms.
-
#list_detectors(params = {}) ⇒ Types::ListDetectorsResponse
Lists detectors (the instances of a detector model).
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
466 467 468 |
# File 'lib/aws-sdk-ioteventsdata/client.rb', line 466 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1019 1020 1021 |
# File 'lib/aws-sdk-ioteventsdata/client.rb', line 1019 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1022 1023 1024 |
# File 'lib/aws-sdk-ioteventsdata/client.rb', line 1022 def errors_module Errors end |
Instance Method Details
#batch_acknowledge_alarm(params = {}) ⇒ Types::BatchAcknowledgeAlarmResponse
Acknowledges one or more alarms. The alarms change to the ‘ACKNOWLEDGED` state after you acknowledge them.
505 506 507 508 |
# File 'lib/aws-sdk-ioteventsdata/client.rb', line 505 def batch_acknowledge_alarm(params = {}, = {}) req = build_request(:batch_acknowledge_alarm, params) req.send_request() end |
#batch_delete_detector(params = {}) ⇒ Types::BatchDeleteDetectorResponse
Deletes one or more detectors that were created. When a detector is deleted, its state will be cleared and the detector will be removed from the list of detectors. The deleted detector will no longer appear if referenced in the [ListDetectors] API call.
[1]: docs.aws.amazon.com/iotevents/latest/apireference/API_iotevents-data_ListDetectors.html
547 548 549 550 |
# File 'lib/aws-sdk-ioteventsdata/client.rb', line 547 def batch_delete_detector(params = {}, = {}) req = build_request(:batch_delete_detector, params) req.send_request() end |
#batch_disable_alarm(params = {}) ⇒ Types::BatchDisableAlarmResponse
Disables one or more alarms. The alarms change to the ‘DISABLED` state after you disable them.
585 586 587 588 |
# File 'lib/aws-sdk-ioteventsdata/client.rb', line 585 def batch_disable_alarm(params = {}, = {}) req = build_request(:batch_disable_alarm, params) req.send_request() end |
#batch_enable_alarm(params = {}) ⇒ Types::BatchEnableAlarmResponse
Enables one or more alarms. The alarms change to the ‘NORMAL` state after you enable them.
623 624 625 626 |
# File 'lib/aws-sdk-ioteventsdata/client.rb', line 623 def batch_enable_alarm(params = {}, = {}) req = build_request(:batch_enable_alarm, params) req.send_request() end |
#batch_put_message(params = {}) ⇒ Types::BatchPutMessageResponse
Sends a set of messages to the IoT Events system. Each message payload is transformed into the input you specify (‘“inputName”`) and ingested into any detectors that monitor that input. If multiple messages are sent, the order in which the messages are processed isn’t guaranteed. To guarantee ordering, you must send messages one at a time and wait for a successful response.
668 669 670 671 |
# File 'lib/aws-sdk-ioteventsdata/client.rb', line 668 def (params = {}, = {}) req = build_request(:batch_put_message, params) req.send_request() end |
#batch_reset_alarm(params = {}) ⇒ Types::BatchResetAlarmResponse
Resets one or more alarms. The alarms return to the ‘NORMAL` state after you reset them.
706 707 708 709 |
# File 'lib/aws-sdk-ioteventsdata/client.rb', line 706 def batch_reset_alarm(params = {}, = {}) req = build_request(:batch_reset_alarm, params) req.send_request() end |
#batch_snooze_alarm(params = {}) ⇒ Types::BatchSnoozeAlarmResponse
Changes one or more alarms to the snooze mode. The alarms change to the ‘SNOOZE_DISABLED` state after you set them to the snooze mode.
745 746 747 748 |
# File 'lib/aws-sdk-ioteventsdata/client.rb', line 745 def batch_snooze_alarm(params = {}, = {}) req = build_request(:batch_snooze_alarm, params) req.send_request() end |
#batch_update_detector(params = {}) ⇒ Types::BatchUpdateDetectorResponse
Updates the state, variable values, and timer settings of one or more detectors (instances) of a specified detector model.
797 798 799 800 |
# File 'lib/aws-sdk-ioteventsdata/client.rb', line 797 def batch_update_detector(params = {}, = {}) req = build_request(:batch_update_detector, params) req.send_request() end |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
992 993 994 995 996 997 998 999 1000 1001 1002 1003 1004 1005 1006 1007 1008 |
# File 'lib/aws-sdk-ioteventsdata/client.rb', line 992 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::IoTEventsData') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-ioteventsdata' context[:gem_version] = '1.59.0' Seahorse::Client::Request.new(handlers, context) end |
#describe_alarm(params = {}) ⇒ Types::DescribeAlarmResponse
Retrieves information about an alarm.
850 851 852 853 |
# File 'lib/aws-sdk-ioteventsdata/client.rb', line 850 def describe_alarm(params = {}, = {}) req = build_request(:describe_alarm, params) req.send_request() end |
#describe_detector(params = {}) ⇒ Types::DescribeDetectorResponse
Returns information about the specified detector (instance).
893 894 895 896 |
# File 'lib/aws-sdk-ioteventsdata/client.rb', line 893 def describe_detector(params = {}, = {}) req = build_request(:describe_detector, params) req.send_request() end |
#list_alarms(params = {}) ⇒ Types::ListAlarmsResponse
Lists one or more alarms. The operation returns only the metadata associated with each alarm.
936 937 938 939 |
# File 'lib/aws-sdk-ioteventsdata/client.rb', line 936 def list_alarms(params = {}, = {}) req = build_request(:list_alarms, params) req.send_request() end |
#list_detectors(params = {}) ⇒ Types::ListDetectorsResponse
Lists detectors (the instances of a detector model).
983 984 985 986 |
# File 'lib/aws-sdk-ioteventsdata/client.rb', line 983 def list_detectors(params = {}, = {}) req = build_request(:list_detectors, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1012 1013 1014 |
# File 'lib/aws-sdk-ioteventsdata/client.rb', line 1012 def waiter_names [] end |