Class: Aws::IoTEventsData::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::IoTEventsData::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-ioteventsdata/client.rb
Overview
An API client for IoTEventsData. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::IoTEventsData::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#batch_acknowledge_alarm(params = {}) ⇒ Types::BatchAcknowledgeAlarmResponse
Acknowledges one or more alarms.
-
#batch_delete_detector(params = {}) ⇒ Types::BatchDeleteDetectorResponse
Deletes one or more detectors that were created.
-
#batch_disable_alarm(params = {}) ⇒ Types::BatchDisableAlarmResponse
Disables one or more alarms.
-
#batch_enable_alarm(params = {}) ⇒ Types::BatchEnableAlarmResponse
Enables one or more alarms.
-
#batch_put_message(params = {}) ⇒ Types::BatchPutMessageResponse
Sends a set of messages to the IoT Events system.
-
#batch_reset_alarm(params = {}) ⇒ Types::BatchResetAlarmResponse
Resets one or more alarms.
-
#batch_snooze_alarm(params = {}) ⇒ Types::BatchSnoozeAlarmResponse
Changes one or more alarms to the snooze mode.
-
#batch_update_detector(params = {}) ⇒ Types::BatchUpdateDetectorResponse
Updates the state, variable values, and timer settings of one or more detectors (instances) of a specified detector model.
-
#describe_alarm(params = {}) ⇒ Types::DescribeAlarmResponse
Retrieves information about an alarm.
-
#describe_detector(params = {}) ⇒ Types::DescribeDetectorResponse
Returns information about the specified detector (instance).
-
#list_alarms(params = {}) ⇒ Types::ListAlarmsResponse
Lists one or more alarms.
-
#list_detectors(params = {}) ⇒ Types::ListDetectorsResponse
Lists detectors (the instances of a detector model).
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
413 414 415 |
# File 'lib/aws-sdk-ioteventsdata/client.rb', line 413 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
961 962 963 |
# File 'lib/aws-sdk-ioteventsdata/client.rb', line 961 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
964 965 966 |
# File 'lib/aws-sdk-ioteventsdata/client.rb', line 964 def errors_module Errors end |
Instance Method Details
#batch_acknowledge_alarm(params = {}) ⇒ Types::BatchAcknowledgeAlarmResponse
Acknowledges one or more alarms. The alarms change to the ‘ACKNOWLEDGED` state after you acknowledge them.
452 453 454 455 |
# File 'lib/aws-sdk-ioteventsdata/client.rb', line 452 def batch_acknowledge_alarm(params = {}, = {}) req = build_request(:batch_acknowledge_alarm, params) req.send_request() end |
#batch_delete_detector(params = {}) ⇒ Types::BatchDeleteDetectorResponse
Deletes one or more detectors that were created. When a detector is deleted, its state will be cleared and the detector will be removed from the list of detectors. The deleted detector will no longer appear if referenced in the [ListDetectors] API call.
[1]: docs.aws.amazon.com/iotevents/latest/apireference/API_iotevents-data_ListDetectors.html
494 495 496 497 |
# File 'lib/aws-sdk-ioteventsdata/client.rb', line 494 def batch_delete_detector(params = {}, = {}) req = build_request(:batch_delete_detector, params) req.send_request() end |
#batch_disable_alarm(params = {}) ⇒ Types::BatchDisableAlarmResponse
Disables one or more alarms. The alarms change to the ‘DISABLED` state after you disable them.
532 533 534 535 |
# File 'lib/aws-sdk-ioteventsdata/client.rb', line 532 def batch_disable_alarm(params = {}, = {}) req = build_request(:batch_disable_alarm, params) req.send_request() end |
#batch_enable_alarm(params = {}) ⇒ Types::BatchEnableAlarmResponse
Enables one or more alarms. The alarms change to the ‘NORMAL` state after you enable them.
570 571 572 573 |
# File 'lib/aws-sdk-ioteventsdata/client.rb', line 570 def batch_enable_alarm(params = {}, = {}) req = build_request(:batch_enable_alarm, params) req.send_request() end |
#batch_put_message(params = {}) ⇒ Types::BatchPutMessageResponse
Sends a set of messages to the IoT Events system. Each message payload is transformed into the input you specify (‘“inputName”`) and ingested into any detectors that monitor that input. If multiple messages are sent, the order in which the messages are processed isn’t guaranteed. To guarantee ordering, you must send messages one at a time and wait for a successful response.
615 616 617 618 |
# File 'lib/aws-sdk-ioteventsdata/client.rb', line 615 def (params = {}, = {}) req = build_request(:batch_put_message, params) req.send_request() end |
#batch_reset_alarm(params = {}) ⇒ Types::BatchResetAlarmResponse
Resets one or more alarms. The alarms return to the ‘NORMAL` state after you reset them.
653 654 655 656 |
# File 'lib/aws-sdk-ioteventsdata/client.rb', line 653 def batch_reset_alarm(params = {}, = {}) req = build_request(:batch_reset_alarm, params) req.send_request() end |
#batch_snooze_alarm(params = {}) ⇒ Types::BatchSnoozeAlarmResponse
Changes one or more alarms to the snooze mode. The alarms change to the ‘SNOOZE_DISABLED` state after you set them to the snooze mode.
692 693 694 695 |
# File 'lib/aws-sdk-ioteventsdata/client.rb', line 692 def batch_snooze_alarm(params = {}, = {}) req = build_request(:batch_snooze_alarm, params) req.send_request() end |
#batch_update_detector(params = {}) ⇒ Types::BatchUpdateDetectorResponse
Updates the state, variable values, and timer settings of one or more detectors (instances) of a specified detector model.
744 745 746 747 |
# File 'lib/aws-sdk-ioteventsdata/client.rb', line 744 def batch_update_detector(params = {}, = {}) req = build_request(:batch_update_detector, params) req.send_request() end |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
939 940 941 942 943 944 945 946 947 948 949 950 |
# File 'lib/aws-sdk-ioteventsdata/client.rb', line 939 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config) context[:gem_name] = 'aws-sdk-ioteventsdata' context[:gem_version] = '1.44.0' Seahorse::Client::Request.new(handlers, context) end |
#describe_alarm(params = {}) ⇒ Types::DescribeAlarmResponse
Retrieves information about an alarm.
797 798 799 800 |
# File 'lib/aws-sdk-ioteventsdata/client.rb', line 797 def describe_alarm(params = {}, = {}) req = build_request(:describe_alarm, params) req.send_request() end |
#describe_detector(params = {}) ⇒ Types::DescribeDetectorResponse
Returns information about the specified detector (instance).
840 841 842 843 |
# File 'lib/aws-sdk-ioteventsdata/client.rb', line 840 def describe_detector(params = {}, = {}) req = build_request(:describe_detector, params) req.send_request() end |
#list_alarms(params = {}) ⇒ Types::ListAlarmsResponse
Lists one or more alarms. The operation returns only the metadata associated with each alarm.
883 884 885 886 |
# File 'lib/aws-sdk-ioteventsdata/client.rb', line 883 def list_alarms(params = {}, = {}) req = build_request(:list_alarms, params) req.send_request() end |
#list_detectors(params = {}) ⇒ Types::ListDetectorsResponse
Lists detectors (the instances of a detector model).
930 931 932 933 |
# File 'lib/aws-sdk-ioteventsdata/client.rb', line 930 def list_detectors(params = {}, = {}) req = build_request(:list_detectors, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
954 955 956 |
# File 'lib/aws-sdk-ioteventsdata/client.rb', line 954 def waiter_names [] end |