Class: Aws::IoTEventsData::Client

Inherits:
Seahorse::Client::Base
  • Object
show all
Includes:
ClientStubs
Defined in:
lib/aws-sdk-ioteventsdata/client.rb

Overview

An API client for IoTEventsData. To construct a client, you need to configure a `:region` and `:credentials`.

client = Aws::IoTEventsData::Client.new(
  region: region_name,
  credentials: credentials,
  # ...
)

For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).

See #initialize for a full list of supported configuration options.

Class Attribute Summary collapse

API Operations collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(options) ⇒ Client

Returns a new instance of Client.

Parameters:

  • options (Hash)

Options Hash (options):

  • :credentials (required, Aws::CredentialProvider)

    Your AWS credentials. This can be an instance of any one of the following classes:

    • `Aws::Credentials` - Used for configuring static, non-refreshing credentials.

    • `Aws::SharedCredentials` - Used for loading static credentials from a shared file, such as `~/.aws/config`.

    • `Aws::AssumeRoleCredentials` - Used when you need to assume a role.

    • `Aws::AssumeRoleWebIdentityCredentials` - Used when you need to assume a role after providing credentials via the web.

    • `Aws::SSOCredentials` - Used for loading credentials from AWS SSO using an access token generated from `aws login`.

    • `Aws::ProcessCredentials` - Used for loading credentials from a process that outputs to stdout.

    • `Aws::InstanceProfileCredentials` - Used for loading credentials from an EC2 IMDS on an EC2 instance.

    • `Aws::ECSCredentials` - Used for loading credentials from instances running in ECS.

    • `Aws::CognitoIdentityCredentials` - Used for loading credentials from the Cognito Identity service.

    When `:credentials` are not configured directly, the following locations will be searched for credentials:

    • `Aws.config`

    • The `:access_key_id`, `:secret_access_key`, and `:session_token` options.

    • ENV, ENV

    • `~/.aws/credentials`

    • `~/.aws/config`

    • EC2/ECS IMDS instance profile - When used by default, the timeouts are very aggressive. Construct and pass an instance of `Aws::InstanceProfileCredentails` or `Aws::ECSCredentials` to enable retries and extended timeouts. Instance profile credential fetching can be disabled by setting ENV to true.

  • :region (required, String)

    The AWS region to connect to. The configured `:region` is used to determine the service `:endpoint`. When not passed, a default `:region` is searched for in the following locations:

  • :access_key_id (String)
  • :active_endpoint_cache (Boolean) — default: false

    When set to `true`, a thread polling for endpoints will be running in the background every 60 secs (default). Defaults to `false`.

  • :adaptive_retry_wait_to_fill (Boolean) — default: true

    Used only in `adaptive` retry mode. When true, the request will sleep until there is sufficent client side capacity to retry the request. When false, the request will raise a `RetryCapacityNotAvailableError` and will not retry instead of sleeping.

  • :client_side_monitoring (Boolean) — default: false

    When `true`, client-side metrics will be collected for all API requests from this client.

  • :client_side_monitoring_client_id (String) — default: ""

    Allows you to provide an identifier for this client which will be attached to all generated client side metrics. Defaults to an empty string.

  • :client_side_monitoring_host (String) — default: "127.0.0.1"

    Allows you to specify the DNS hostname or IPv4 or IPv6 address that the client side monitoring agent is running on, where client metrics will be published via UDP.

  • :client_side_monitoring_port (Integer) — default: 31000

    Required for publishing client metrics. The port that the client side monitoring agent is running on, where client metrics will be published via UDP.

  • :client_side_monitoring_publisher (Aws::ClientSideMonitoring::Publisher) — default: Aws::ClientSideMonitoring::Publisher

    Allows you to provide a custom client-side monitoring publisher class. By default, will use the Client Side Monitoring Agent Publisher.

  • :convert_params (Boolean) — default: true

    When `true`, an attempt is made to coerce request parameters into the required types.

  • :correct_clock_skew (Boolean) — default: true

    Used only in `standard` and adaptive retry modes. Specifies whether to apply a clock skew correction and retry requests with skewed client clocks.

  • :defaults_mode (String) — default: "legacy"

    See DefaultsModeConfiguration for a list of the accepted modes and the configuration defaults that are included.

  • :disable_host_prefix_injection (Boolean) — default: false

    Set to true to disable SDK automatically adding host prefix to default service endpoint when available.

  • :endpoint (String)

    The client endpoint is normally constructed from the `:region` option. You should only configure an `:endpoint` when connecting to test or custom endpoints. This should be a valid HTTP(S) URI.

  • :endpoint_cache_max_entries (Integer) — default: 1000

    Used for the maximum size limit of the LRU cache storing endpoints data for endpoint discovery enabled operations. Defaults to 1000.

  • :endpoint_cache_max_threads (Integer) — default: 10

    Used for the maximum threads in use for polling endpoints to be cached, defaults to 10.

  • :endpoint_cache_poll_interval (Integer) — default: 60

    When :endpoint_discovery and :active_endpoint_cache is enabled, Use this option to config the time interval in seconds for making requests fetching endpoints information. Defaults to 60 sec.

  • :endpoint_discovery (Boolean) — default: false

    When set to `true`, endpoint discovery will be enabled for operations when available.

  • :log_formatter (Aws::Log::Formatter) — default: Aws::Log::Formatter.default

    The log formatter.

  • :log_level (Symbol) — default: :info

    The log level to send messages to the `:logger` at.

  • :logger (Logger)

    The Logger instance to send log messages to. If this option is not set, logging will be disabled.

  • :max_attempts (Integer) — default: 3

    An integer representing the maximum number attempts that will be made for a single request, including the initial attempt. For example, setting this value to 5 will result in a request being retried up to 4 times. Used in `standard` and `adaptive` retry modes.

  • :profile (String) — default: "default"

    Used when loading credentials from the shared credentials file at HOME/.aws/credentials. When not specified, 'default' is used.

  • :retry_backoff (Proc)

    A proc or lambda used for backoff. Defaults to 2**retries * retry_base_delay. This option is only used in the `legacy` retry mode.

  • :retry_base_delay (Float) — default: 0.3

    The base delay in seconds used by the default backoff function. This option is only used in the `legacy` retry mode.

  • :retry_jitter (Symbol) — default: :none

    A delay randomiser function used by the default backoff function. Some predefined functions can be referenced by name - :none, :equal, :full, otherwise a Proc that takes and returns a number. This option is only used in the `legacy` retry mode.

    @see www.awsarchitectureblog.com/2015/03/backoff.html

  • :retry_limit (Integer) — default: 3

    The maximum number of times to retry failed requests. Only ~ 500 level server errors and certain ~ 400 level client errors are retried. Generally, these are throttling errors, data checksum errors, networking errors, timeout errors, auth errors, endpoint discovery, and errors from expired credentials. This option is only used in the `legacy` retry mode.

  • :retry_max_delay (Integer) — default: 0

    The maximum number of seconds to delay between retries (0 for no limit) used by the default backoff function. This option is only used in the `legacy` retry mode.

  • :retry_mode (String) — default: "legacy"

    Specifies which retry algorithm to use. Values are:

    • `legacy` - The pre-existing retry behavior. This is default value if no retry mode is provided.

    • `standard` - A standardized set of retry rules across the AWS SDKs. This includes support for retry quotas, which limit the number of unsuccessful retries a client can make.

    • `adaptive` - An experimental retry mode that includes all the functionality of `standard` mode along with automatic client side throttling. This is a provisional mode that may change behavior in the future.

  • :secret_access_key (String)
  • :session_token (String)
  • :stub_responses (Boolean) — default: false

    Causes the client to return stubbed responses. By default fake responses are generated and returned. You can specify the response data to return or errors to raise by calling ClientStubs#stub_responses. See ClientStubs for more information.

    ** Please note ** When response stubbing is enabled, no HTTP requests are made, and retries are disabled.

  • :use_dualstack_endpoint (Boolean)

    When set to `true`, dualstack enabled endpoints (with `.aws` TLD) will be used if available.

  • :use_fips_endpoint (Boolean)

    When set to `true`, fips compatible endpoints will be used if available. When a `fips` region is used, the region is normalized and this config is set to `true`.

  • :validate_params (Boolean) — default: true

    When `true`, request parameters are validated before sending the request.

  • :http_proxy (URI::HTTP, String)

    A proxy to send requests through. Formatted like 'proxy.com:123'.

  • :http_open_timeout (Float) — default: 15

    The number of seconds to wait when opening a HTTP session before raising a `Timeout::Error`.

  • :http_read_timeout (Float) — default: 60

    The default number of seconds to wait for response data. This value can safely be set per-request on the session.

  • :http_idle_timeout (Float) — default: 5

    The number of seconds a connection is allowed to sit idle before it is considered stale. Stale connections are closed and removed from the pool before making a request.

  • :http_continue_timeout (Float) — default: 1

    The number of seconds to wait for a 100-continue response before sending the request body. This option has no effect unless the request has “Expect” header set to “100-continue”. Defaults to `nil` which disables this behaviour. This value can safely be set per request on the session.

  • :ssl_timeout (Float) — default: nil

    Sets the SSL timeout in seconds.

  • :http_wire_trace (Boolean) — default: false

    When `true`, HTTP debug output will be sent to the `:logger`.

  • :ssl_verify_peer (Boolean) — default: true

    When `true`, SSL peer certificates are verified when establishing a connection.

  • :ssl_ca_bundle (String)

    Full path to the SSL certificate authority bundle file that should be used when verifying peer certificates. If you do not pass `:ssl_ca_bundle` or `:ssl_ca_directory` the the system default will be used if available.

  • :ssl_ca_directory (String)

    Full path of the directory that contains the unbundled SSL certificate authority files for verifying peer certificates. If you do not pass `:ssl_ca_bundle` or `:ssl_ca_directory` the the system default will be used if available.



344
345
346
# File 'lib/aws-sdk-ioteventsdata/client.rb', line 344

def initialize(*args)
  super
end

Class Attribute Details

.identifierObject (readonly)

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.



850
851
852
# File 'lib/aws-sdk-ioteventsdata/client.rb', line 850

def identifier
  @identifier
end

Class Method Details

.errors_moduleObject

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.



853
854
855
# File 'lib/aws-sdk-ioteventsdata/client.rb', line 853

def errors_module
  Errors
end

Instance Method Details

#batch_acknowledge_alarm(params = {}) ⇒ Types::BatchAcknowledgeAlarmResponse

Acknowledges one or more alarms. The alarms change to the `ACKNOWLEDGED` state after you acknowledge them.

Examples:

Request syntax with placeholder values


resp = client.batch_acknowledge_alarm({
  acknowledge_action_requests: [ # required
    {
      request_id: "RequestId", # required
      alarm_model_name: "AlarmModelName", # required
      key_value: "KeyValue",
      note: "Note",
    },
  ],
})

Response structure


resp.error_entries #=> Array
resp.error_entries[0].request_id #=> String
resp.error_entries[0].error_code #=> String, one of "ResourceNotFoundException", "InvalidRequestException", "InternalFailureException", "ServiceUnavailableException", "ThrottlingException"
resp.error_entries[0].error_message #=> String

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :acknowledge_action_requests (required, Array<Types::AcknowledgeAlarmActionRequest>)

    The list of acknowledge action requests. You can specify up to 10 requests per operation.

Returns:



383
384
385
386
# File 'lib/aws-sdk-ioteventsdata/client.rb', line 383

def batch_acknowledge_alarm(params = {}, options = {})
  req = build_request(:batch_acknowledge_alarm, params)
  req.send_request(options)
end

#batch_disable_alarm(params = {}) ⇒ Types::BatchDisableAlarmResponse

Disables one or more alarms. The alarms change to the `DISABLED` state after you disable them.

Examples:

Request syntax with placeholder values


resp = client.batch_disable_alarm({
  disable_action_requests: [ # required
    {
      request_id: "RequestId", # required
      alarm_model_name: "AlarmModelName", # required
      key_value: "KeyValue",
      note: "Note",
    },
  ],
})

Response structure


resp.error_entries #=> Array
resp.error_entries[0].request_id #=> String
resp.error_entries[0].error_code #=> String, one of "ResourceNotFoundException", "InvalidRequestException", "InternalFailureException", "ServiceUnavailableException", "ThrottlingException"
resp.error_entries[0].error_message #=> String

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :disable_action_requests (required, Array<Types::DisableAlarmActionRequest>)

    The list of disable action requests. You can specify up to 10 requests per operation.

Returns:



421
422
423
424
# File 'lib/aws-sdk-ioteventsdata/client.rb', line 421

def batch_disable_alarm(params = {}, options = {})
  req = build_request(:batch_disable_alarm, params)
  req.send_request(options)
end

#batch_enable_alarm(params = {}) ⇒ Types::BatchEnableAlarmResponse

Enables one or more alarms. The alarms change to the `NORMAL` state after you enable them.

Examples:

Request syntax with placeholder values


resp = client.batch_enable_alarm({
  enable_action_requests: [ # required
    {
      request_id: "RequestId", # required
      alarm_model_name: "AlarmModelName", # required
      key_value: "KeyValue",
      note: "Note",
    },
  ],
})

Response structure


resp.error_entries #=> Array
resp.error_entries[0].request_id #=> String
resp.error_entries[0].error_code #=> String, one of "ResourceNotFoundException", "InvalidRequestException", "InternalFailureException", "ServiceUnavailableException", "ThrottlingException"
resp.error_entries[0].error_message #=> String

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :enable_action_requests (required, Array<Types::EnableAlarmActionRequest>)

    The list of enable action requests. You can specify up to 10 requests per operation.

Returns:



459
460
461
462
# File 'lib/aws-sdk-ioteventsdata/client.rb', line 459

def batch_enable_alarm(params = {}, options = {})
  req = build_request(:batch_enable_alarm, params)
  req.send_request(options)
end

#batch_put_message(params = {}) ⇒ Types::BatchPutMessageResponse

Sends a set of messages to the IoT Events system. Each message payload is transformed into the input you specify (`“inputName”`) and ingested into any detectors that monitor that input. If multiple messages are sent, the order in which the messages are processed isn't guaranteed. To guarantee ordering, you must send messages one at a time and wait for a successful response.

Examples:

Request syntax with placeholder values


resp = client.batch_put_message({
  messages: [ # required
    {
      message_id: "MessageId", # required
      input_name: "EphemeralInputName", # required
      payload: "data", # required
      timestamp: {
        time_in_millis: 1,
      },
    },
  ],
})

Response structure


resp.batch_put_message_error_entries #=> Array
resp.batch_put_message_error_entries[0].message_id #=> String
resp.batch_put_message_error_entries[0].error_code #=> String, one of "ResourceNotFoundException", "InvalidRequestException", "InternalFailureException", "ServiceUnavailableException", "ThrottlingException"
resp.batch_put_message_error_entries[0].error_message #=> String

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :messages (required, Array<Types::Message>)

    The list of messages to send. Each message has the following format: `'{ “messageId”: “string”, “inputName”: “string”, “payload”: “string”}'`

Returns:



504
505
506
507
# File 'lib/aws-sdk-ioteventsdata/client.rb', line 504

def batch_put_message(params = {}, options = {})
  req = build_request(:batch_put_message, params)
  req.send_request(options)
end

#batch_reset_alarm(params = {}) ⇒ Types::BatchResetAlarmResponse

Resets one or more alarms. The alarms return to the `NORMAL` state after you reset them.

Examples:

Request syntax with placeholder values


resp = client.batch_reset_alarm({
  reset_action_requests: [ # required
    {
      request_id: "RequestId", # required
      alarm_model_name: "AlarmModelName", # required
      key_value: "KeyValue",
      note: "Note",
    },
  ],
})

Response structure


resp.error_entries #=> Array
resp.error_entries[0].request_id #=> String
resp.error_entries[0].error_code #=> String, one of "ResourceNotFoundException", "InvalidRequestException", "InternalFailureException", "ServiceUnavailableException", "ThrottlingException"
resp.error_entries[0].error_message #=> String

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :reset_action_requests (required, Array<Types::ResetAlarmActionRequest>)

    The list of reset action requests. You can specify up to 10 requests per operation.

Returns:



542
543
544
545
# File 'lib/aws-sdk-ioteventsdata/client.rb', line 542

def batch_reset_alarm(params = {}, options = {})
  req = build_request(:batch_reset_alarm, params)
  req.send_request(options)
end

#batch_snooze_alarm(params = {}) ⇒ Types::BatchSnoozeAlarmResponse

Changes one or more alarms to the snooze mode. The alarms change to the `SNOOZE_DISABLED` state after you set them to the snooze mode.

Examples:

Request syntax with placeholder values


resp = client.batch_snooze_alarm({
  snooze_action_requests: [ # required
    {
      request_id: "RequestId", # required
      alarm_model_name: "AlarmModelName", # required
      key_value: "KeyValue",
      note: "Note",
      snooze_duration: 1, # required
    },
  ],
})

Response structure


resp.error_entries #=> Array
resp.error_entries[0].request_id #=> String
resp.error_entries[0].error_code #=> String, one of "ResourceNotFoundException", "InvalidRequestException", "InternalFailureException", "ServiceUnavailableException", "ThrottlingException"
resp.error_entries[0].error_message #=> String

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :snooze_action_requests (required, Array<Types::SnoozeAlarmActionRequest>)

    The list of snooze action requests. You can specify up to 10 requests per operation.

Returns:



581
582
583
584
# File 'lib/aws-sdk-ioteventsdata/client.rb', line 581

def batch_snooze_alarm(params = {}, options = {})
  req = build_request(:batch_snooze_alarm, params)
  req.send_request(options)
end

#batch_update_detector(params = {}) ⇒ Types::BatchUpdateDetectorResponse

Updates the state, variable values, and timer settings of one or more detectors (instances) of a specified detector model.

Examples:

Request syntax with placeholder values


resp = client.batch_update_detector({
  detectors: [ # required
    {
      message_id: "MessageId", # required
      detector_model_name: "DetectorModelName", # required
      key_value: "KeyValue",
      state: { # required
        state_name: "StateName", # required
        variables: [ # required
          {
            name: "VariableName", # required
            value: "VariableValue", # required
          },
        ],
        timers: [ # required
          {
            name: "TimerName", # required
            seconds: 1, # required
          },
        ],
      },
    },
  ],
})

Response structure


resp.batch_update_detector_error_entries #=> Array
resp.batch_update_detector_error_entries[0].message_id #=> String
resp.batch_update_detector_error_entries[0].error_code #=> String, one of "ResourceNotFoundException", "InvalidRequestException", "InternalFailureException", "ServiceUnavailableException", "ThrottlingException"
resp.batch_update_detector_error_entries[0].error_message #=> String

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :detectors (required, Array<Types::UpdateDetectorRequest>)

    The list of detectors (instances) to update, along with the values to update.

Returns:



633
634
635
636
# File 'lib/aws-sdk-ioteventsdata/client.rb', line 633

def batch_update_detector(params = {}, options = {})
  req = build_request(:batch_update_detector, params)
  req.send_request(options)
end

#build_request(operation_name, params = {}) ⇒ Object

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Parameters:

  • params ({}) (defaults to: {})


828
829
830
831
832
833
834
835
836
837
838
839
# File 'lib/aws-sdk-ioteventsdata/client.rb', line 828

def build_request(operation_name, params = {})
  handlers = @handlers.for(operation_name)
  context = Seahorse::Client::RequestContext.new(
    operation_name: operation_name,
    operation: config.api.operation(operation_name),
    client: self,
    params: params,
    config: config)
  context[:gem_name] = 'aws-sdk-ioteventsdata'
  context[:gem_version] = '1.24.0'
  Seahorse::Client::Request.new(handlers, context)
end

#describe_alarm(params = {}) ⇒ Types::DescribeAlarmResponse

Retrieves information about an alarm.

Examples:

Request syntax with placeholder values


resp = client.describe_alarm({
  alarm_model_name: "AlarmModelName", # required
  key_value: "KeyValue",
})

Response structure


resp.alarm.alarm_model_name #=> String
resp.alarm.alarm_model_version #=> String
resp.alarm.key_value #=> String
resp.alarm.alarm_state.state_name #=> String, one of "DISABLED", "NORMAL", "ACTIVE", "ACKNOWLEDGED", "SNOOZE_DISABLED", "LATCHED"
resp.alarm.alarm_state.rule_evaluation.simple_rule_evaluation.input_property_value #=> String
resp.alarm.alarm_state.rule_evaluation.simple_rule_evaluation.operator #=> String, one of "GREATER", "GREATER_OR_EQUAL", "LESS", "LESS_OR_EQUAL", "EQUAL", "NOT_EQUAL"
resp.alarm.alarm_state.rule_evaluation.simple_rule_evaluation.threshold_value #=> String
resp.alarm.alarm_state.customer_action.action_name #=> String, one of "SNOOZE", "ENABLE", "DISABLE", "ACKNOWLEDGE", "RESET"
resp.alarm.alarm_state.customer_action.snooze_action_configuration.snooze_duration #=> Integer
resp.alarm.alarm_state.customer_action.snooze_action_configuration.note #=> String
resp.alarm.alarm_state.customer_action.enable_action_configuration.note #=> String
resp.alarm.alarm_state.customer_action.disable_action_configuration.note #=> String
resp.alarm.alarm_state.customer_action.acknowledge_action_configuration.note #=> String
resp.alarm.alarm_state.customer_action.reset_action_configuration.note #=> String
resp.alarm.alarm_state.system_event.event_type #=> String, one of "STATE_CHANGE"
resp.alarm.alarm_state.system_event.state_change_configuration.trigger_type #=> String, one of "SNOOZE_TIMEOUT"
resp.alarm.severity #=> Integer
resp.alarm.creation_time #=> Time
resp.alarm.last_update_time #=> Time

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

Returns:



686
687
688
689
# File 'lib/aws-sdk-ioteventsdata/client.rb', line 686

def describe_alarm(params = {}, options = {})
  req = build_request(:describe_alarm, params)
  req.send_request(options)
end

#describe_detector(params = {}) ⇒ Types::DescribeDetectorResponse

Returns information about the specified detector (instance).

Examples:

Request syntax with placeholder values


resp = client.describe_detector({
  detector_model_name: "DetectorModelName", # required
  key_value: "KeyValue",
})

Response structure


resp.detector.detector_model_name #=> String
resp.detector.key_value #=> String
resp.detector.detector_model_version #=> String
resp.detector.state.state_name #=> String
resp.detector.state.variables #=> Array
resp.detector.state.variables[0].name #=> String
resp.detector.state.variables[0].value #=> String
resp.detector.state.timers #=> Array
resp.detector.state.timers[0].name #=> String
resp.detector.state.timers[0].timestamp #=> Time
resp.detector.creation_time #=> Time
resp.detector.last_update_time #=> Time

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :detector_model_name (required, String)

    The name of the detector model whose detectors (instances) you want information about.

  • :key_value (String)

    A filter used to limit results to detectors (instances) created because of the given key ID.

Returns:



729
730
731
732
# File 'lib/aws-sdk-ioteventsdata/client.rb', line 729

def describe_detector(params = {}, options = {})
  req = build_request(:describe_detector, params)
  req.send_request(options)
end

#list_alarms(params = {}) ⇒ Types::ListAlarmsResponse

Lists one or more alarms. The operation returns only the metadata associated with each alarm.

Examples:

Request syntax with placeholder values


resp = client.list_alarms({
  alarm_model_name: "AlarmModelName", # required
  next_token: "NextToken",
  max_results: 1,
})

Response structure


resp.alarm_summaries #=> Array
resp.alarm_summaries[0].alarm_model_name #=> String
resp.alarm_summaries[0].alarm_model_version #=> String
resp.alarm_summaries[0].key_value #=> String
resp.alarm_summaries[0].state_name #=> String, one of "DISABLED", "NORMAL", "ACTIVE", "ACKNOWLEDGED", "SNOOZE_DISABLED", "LATCHED"
resp.alarm_summaries[0].creation_time #=> Time
resp.alarm_summaries[0].last_update_time #=> Time
resp.next_token #=> String

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :alarm_model_name (required, String)

    The name of the alarm model.

  • :next_token (String)

    The token that you can use to return the next set of results.

  • :max_results (Integer)

    The maximum number of results to be returned per request.

Returns:



772
773
774
775
# File 'lib/aws-sdk-ioteventsdata/client.rb', line 772

def list_alarms(params = {}, options = {})
  req = build_request(:list_alarms, params)
  req.send_request(options)
end

#list_detectors(params = {}) ⇒ Types::ListDetectorsResponse

Lists detectors (the instances of a detector model).

Examples:

Request syntax with placeholder values


resp = client.list_detectors({
  detector_model_name: "DetectorModelName", # required
  state_name: "StateName",
  next_token: "NextToken",
  max_results: 1,
})

Response structure


resp.detector_summaries #=> Array
resp.detector_summaries[0].detector_model_name #=> String
resp.detector_summaries[0].key_value #=> String
resp.detector_summaries[0].detector_model_version #=> String
resp.detector_summaries[0].state.state_name #=> String
resp.detector_summaries[0].creation_time #=> Time
resp.detector_summaries[0].last_update_time #=> Time
resp.next_token #=> String

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :detector_model_name (required, String)

    The name of the detector model whose detectors (instances) are listed.

  • :state_name (String)

    A filter that limits results to those detectors (instances) in the given state.

  • :next_token (String)

    The token that you can use to return the next set of results.

  • :max_results (Integer)

    The maximum number of results to be returned per request.

Returns:



819
820
821
822
# File 'lib/aws-sdk-ioteventsdata/client.rb', line 819

def list_detectors(params = {}, options = {})
  req = build_request(:list_detectors, params)
  req.send_request(options)
end

#waiter_namesObject

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Deprecated.


843
844
845
# File 'lib/aws-sdk-ioteventsdata/client.rb', line 843

def waiter_names
  []
end