Class: Aws::IoTEventsData::Types::EnableAlarmActionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTEventsData::Types::EnableAlarmActionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ioteventsdata/types.rb
Overview
Note:
When making an API call, you may pass EnableAlarmActionRequest data as a hash:
{
request_id: "RequestId", # required
alarm_model_name: "AlarmModelName", # required
key_value: "KeyValue",
note: "Note",
}
Information needed to enable the alarm.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#alarm_model_name ⇒ String
The name of the alarm model.
-
#key_value ⇒ String
The value of the key used as a filter to select only the alarms associated with the [key].
-
#note ⇒ String
The note that you can leave when you enable the alarm.
-
#request_id ⇒ String
The request ID.
Instance Attribute Details
#alarm_model_name ⇒ String
The name of the alarm model.
1085 1086 1087 1088 1089 1090 1091 1092 |
# File 'lib/aws-sdk-ioteventsdata/types.rb', line 1085 class EnableAlarmActionRequest < Struct.new( :request_id, :alarm_model_name, :key_value, :note) SENSITIVE = [] include Aws::Structure end |
#key_value ⇒ String
The value of the key used as a filter to select only the alarms associated with the [key].
1085 1086 1087 1088 1089 1090 1091 1092 |
# File 'lib/aws-sdk-ioteventsdata/types.rb', line 1085 class EnableAlarmActionRequest < Struct.new( :request_id, :alarm_model_name, :key_value, :note) SENSITIVE = [] include Aws::Structure end |
#note ⇒ String
The note that you can leave when you enable the alarm.
1085 1086 1087 1088 1089 1090 1091 1092 |
# File 'lib/aws-sdk-ioteventsdata/types.rb', line 1085 class EnableAlarmActionRequest < Struct.new( :request_id, :alarm_model_name, :key_value, :note) SENSITIVE = [] include Aws::Structure end |
#request_id ⇒ String
The request ID. Each ID must be unique within each batch.
1085 1086 1087 1088 1089 1090 1091 1092 |
# File 'lib/aws-sdk-ioteventsdata/types.rb', line 1085 class EnableAlarmActionRequest < Struct.new( :request_id, :alarm_model_name, :key_value, :note) SENSITIVE = [] include Aws::Structure end |